@@ -20,7 +20,7 @@ from osc_lib.command import command
 from osc_lib import exceptions as exc
 from osc_lib import utils
 
-from senlinclient.common.i18n import _, _LI
+from senlinclient.common.i18n import _
 from senlinclient.common import utils as senlin_utils
 
 
@@ -37,7 +37,8 @@ class ListReceiver(command.Lister):
             help=_("Filter parameters to apply on returned receivers. "
                    "This can be specified multiple times, or once with "
                    "parameters separated by a semicolon. The valid filter "
-                   "keys are: ['name', 'type', 'action', 'cluster_id']"),
+                   "keys are: ['name', 'type', 'action', 'cluster_id', "
+                   "'user_id']"),
             action='append'
         )
         parser.add_argument(
@@ -96,6 +97,7 @@ class ListReceiver(command.Lister):
         formatters = {}
         if parsed_args.global_project:
             columns.append('project_id')
+            columns.append('user_id')
         if not parsed_args.full_id:
             formatters = {
                 'id': lambda x: x[:8],
@@ -103,6 +105,7 @@ class ListReceiver(command.Lister):
             }
             if 'project_id' in columns:
                 formatters['project_id'] = lambda x: x[:8]
+                formatters['user_id'] = lambda x: x[:8]
 
         return (
             columns,
@@ -243,10 +246,10 @@ class DeleteReceiver(command.Command):
                 if not prompt_response.startswith('y'):
                     return
         except KeyboardInterrupt:  # Ctrl-c
-            self.log.info(_LI('Ctrl-c detected.'))
+            self.log.info('Ctrl-c detected.')
             return
         except EOFError:  # Ctrl-d
-            self.log.info(_LI('Ctrl-d detected'))
+            self.log.info('Ctrl-d detected')
             return
 
         failure_count = 0
